# DM23004UNO

Esta librería resuelve sistemas de ecuaciones lineales y no lineales usando diferentes métodos matemáticos.

## Métodos disponibles:

- Eliminación de Gauss
- Gauss-Jordan
- Cramer
- Descomposición LU
- Jacobi
- Gauss-Seidel
- Bisección

## Instalación

Puedes instalar esta librería usando pip:

```bash
pip install DM23004UNO
